@@ -1,4 +1,5 @@
-// $Id: wvsrtv.cc 28 2006-03-14 01:59:34Z flaterco $
+// $Id: wvsrtv.cc 3551 2009-12-22 23:56:35Z flaterco $
+
 /*  wvsrtv  Retrieve WVS data from compressed files.
 
 
@@ -12,21 +13,21 @@
 
 
         The following functions are used to access the compressed World
-    Vector Shoreline (WVS) files as they were stored on the National 
-    Geophysical Data Center (NGDC) Global Relief Data CD-ROM.  These files, 
-    and the compression method used on them, were designed and built by 
-    myself and James Hammack (then of NORDA).  The work was done in 1989.  
-    At that time the 350MB that was required to store the entire WVS data 
-    set was considered too large to deal with easily.  In addition, the data 
-    was sequential access, ASCII format which required that you read the 
-    entire data set to retrieve all of the data for any subset.  The data is 
-    stored in a direct access data file as unsigned character data.  There 
+    Vector Shoreline (WVS) files as they were stored on the National
+    Geophysical Data Center (NGDC) Global Relief Data CD-ROM.  These files,
+    and the compression method used on them, were designed and built by
+    myself and James Hammack (then of NORDA).  The work was done in 1989.
+    At that time the 350MB that was required to store the entire WVS data
+    set was considered too large to deal with easily.  In addition, the data
+    was sequential access, ASCII format which required that you read the
+    entire data set to retrieve all of the data for any subset.  The data is
+    stored in a direct access data file as unsigned character data.  There
     are no endian or floating point format issues with this data set.  It is
     organized by one-degree cells so that any one-degree cell is accessible
     with two reads.  The compression used is a simple delta coding method.
     The full resolution data set was compressed from 350MB to 25MB.  In
-    addition to the full resolution data set, which was slightly better than 
-    1:250,000 scale, Jerry Landrum (NORDA) used the Douglas-Peuker algorithm 
+    addition to the full resolution data set, which was slightly better than
+    1:250,000 scale, Jerry Landrum (NORDA) used the Douglas-Peuker algorithm
     to sub-sample the data to lower resolution data sets.  The resulting
     files were then compressed using our method to produce the following
     files:
@@ -38,7 +39,7 @@
         wvs12.dat      -    1:12,000,000        -    2,933,760 bytes
         wvs43.dat      -    1:43,000,000        -    2,233,344 bytes
 
-    Notice that the 1:3,000,000 scale data set is actually larger than the 
+    Notice that the 1:3,000,000 scale data set is actually larger than the
     1:1,000,000 scale data set.  Go figure.  There isn't much use in using
     the 1:3,000,000 scale data set unless you just want less detailed
     shorelines.  The NGDC Global Relief Data CD-ROM also contains the CIA
@@ -50,13 +51,13 @@
     seems worth the effort (which is why I didn't do it).
 
         For the masochistic I recommend reading A Portable Method For
-    Compressing and Storing High-Resolution Geographic Data Sets, Jan C. 
-    Depner and James A. Hammack, Naval Oceanographic Office, 1989.  It 
-    describes the compression, storage, and retrieving methods in painful 
-    detail.  Every time I read it I get confused all over again. 
+    Compressing and Storing High-Resolution Geographic Data Sets, Jan C.
+    Depner and James A. Hammack, Naval Oceanographic Office, 1989.  It
+    describes the compression, storage, and retrieving methods in painful
+    detail.  Every time I read it I get confused all over again.
 
-        The following functions allow the user to retrieve the data from 
-    the data files one degree at a time.  This is the way I should have done 
+        The following functions allow the user to retrieve the data from
+    the data files one degree at a time.  This is the way I should have done
     it in the first place.  You must define an environment variable (WVS_DIR)
     that points to the directory containing the coastline files.  The
     coastline files must use the names defined above (as they were stored on
@@ -85,20 +86,17 @@
 #include <string.h>
 #include <errno.h>
 #include <math.h>
-
-// DWF: gotta have my Dstrs
 #include <assert.h>
-#include "Dstr.hh"
 
 
 #define         PHYSIZ      3072
- 
+
 #define         SIGN_OF(x)  ((x)<0.0 ? -1 : 1)
- 
+
 
 //RWL make paths either WIN or Unix
 
-#ifdef WIN32
+#if defined(WIN32) || defined(_MSC_VER)
 #define DIR_PATH_CHAR "\\"
 #else
 #define DIR_PATH_CHAR "/"
@@ -140,36 +138,41 @@
 *                                                                           *
 \***************************************************************************/
 
-static void nxtrec (long *rindex, unsigned char *bytbuf, long *curpos, 
+static void nxtrec (long *rindex, unsigned char *bytbuf, long *curpos,
                     long *addr, int lperp, long *paddr, FILE *fp, int logrec)
 {
-    int        stat;
-
-
     /*  Compute the index number for the next logical record in the chain.   */
-    
-    *rindex = bytbuf[*curpos + 1] * (long) 65536 + bytbuf[*curpos + 2] * 
+
+    *rindex = bytbuf[*curpos + 1] * (long) 65536 + bytbuf[*curpos + 2] *
         (long) 256 + bytbuf[*curpos + 3];
     *addr = ((*rindex - 1) / lperp) * PHYSIZ;
 
 
-    /*  If the physical record has changed since the last access, read a 
+    /*  If the physical record has changed since the last access, read a
         new physical record.  */
-    
+
     if (*addr != *paddr)
     {
-        stat = fseek (fp, *addr, 0);
-        stat = fread (bytbuf, PHYSIZ, 1, fp);
+      // DWF added error checking
+      if (fseek (fp, *addr, 0)) {
+        fprintf (stderr, "nxtrec:  error on fseek\n");
+        perror ("nxtrec");
+        exit (-1);
+      }
+      if (fread (bytbuf, PHYSIZ, 1, fp) < 1) {
+        fprintf (stderr, "nxtrec:  error on fread\n");
+        exit (-1);
+      }
     }
 
 
-    /*  Set the previous physical address to the current one, and compute 
+    /*  Set the previous physical address to the current one, and compute
         the current byte position for the new record.  */
-    
+
     *paddr = *addr;
     *curpos = ((*rindex - 1) % lperp) * logrec;
 }
- 
+
 
 
 /***************************************************************************\
@@ -208,8 +211,8 @@ static void nxtrec (long *rindex, unsigned char *bytbuf, long *curpos,
 *                                                                           *
 \***************************************************************************/
 
-static void movpos (long *rindex, unsigned char *bytbuf, long *curpos, 
-                    long *addr, int lperp, long *paddr, FILE *fp, int logrec, 
+static void movpos (long *rindex, unsigned char *bytbuf, long *curpos,
+                    long *addr, int lperp, long *paddr, FILE *fp, int logrec,
                     long fulrec)
 {
     *curpos = *curpos + 2;
@@ -217,10 +220,10 @@ static void movpos (long *rindex, unsigned char *bytbuf, long *curpos,
 
     /*  If we hit the end of the physical record, get the next one.  */
 
-    if (*curpos % logrec == fulrec) nxtrec (rindex, bytbuf, curpos, addr, 
+    if (*curpos % logrec == fulrec) nxtrec (rindex, bytbuf, curpos, addr,
         lperp, paddr, fp, logrec);
 }
- 
+
 
 
 /***************************************************************************\
@@ -255,10 +258,10 @@ static int test_bit (unsigned char byte, int bitpos)
 {
     static unsigned char    mask[9] = {0x1, 0x2, 0x4, 0x8, 0x10, 0x20,
                             0x40, 0x80};
- 
+
     return (byte & mask[bitpos]);
 }
- 
+
 
 
 /***************************************************************************\
@@ -307,55 +310,63 @@ static int celchk (int rindex, int logrec, int offset, FILE *fp, long *pcaddr)
     static unsigned char    celbuf[PHYSIZ];
     static long             caddr;
     long                    ndxpos;
-    int                     bytpos, bitpos, chk, stat;
+    int                     bytpos, bitpos, chk;
 
 
     /*  Compute the physical address of the 'rindex' cell bit. */
-    
+
     caddr = (((rindex + logrec * 8) - (offset + 1)) /
         (PHYSIZ * 8)) * PHYSIZ;
 
 
-    /*  If this is the first access or the physical address has changed 
+    /*  If this is the first access or the physical address has changed
         since the last access, read a new physical record.  */
-    
+
     if (*pcaddr != caddr)
     {
-        stat = fseek (fp, caddr, 0);
-        stat = fread (celbuf, PHYSIZ, 1, fp);
+      // DWF added error checking
+      if (fseek (fp, caddr, 0)) {
+        fprintf (stderr, "celchk:  error on fseek\n");
+        perror ("celchk");
+        exit (-1);
+      }
+      if (fread (celbuf, PHYSIZ, 1, fp) < 1) {
+        fprintf (stderr, "celchk:  error on fread\n");
+        exit (-1);
+      }
     }
 
 
     /*  Set the previous address to the current one.  */
-    
+
     *pcaddr = caddr;
 
 
     /*  Compute the 'rindex' position within the physical record.  */
-    
+
     ndxpos = ((rindex + logrec * 8) - (offset + 1)) % (PHYSIZ * 8);
 
 
     /*  Compute the byte and bit positions.  */
-    
+
     bytpos = ndxpos / 8;
     bitpos = 7 - ndxpos % 8;
 
 
     /*  Test the 'rindex' bit and return.  */
-    
+
     chk = test_bit (celbuf[bytpos], bitpos);
     return (chk);
 }
- 
+
 
 
 
 /***************************************************************************\
-*	Function build_seg                                                  *
+*       Function build_seg                                                  *
 *****************************************************************************
 *                                                                           *
-*	Build the arrays containing the segments.                           *
+*       Build the arrays containing the segments.                           *
 *                                                                           *
 *       Author :                                                            *
 *                                                                           *
@@ -368,11 +379,11 @@ static int celchk (int rindex, int logrec, int offset, FILE *fp, long *pcaddr)
 *         depnerj@navo.navy.mil                                             *
 *                                                                           *
 *                                                                           *
-*	Arguments:                                                          *
+*       Arguments:                                                          *
 *                                                                           *
-*	dlat   - latitude of current point (degrees)                        *
-*	dlon   - longitude of current point (degrees)                       *
-*	cont   - segment continuation flag.                                 *
+*       dlat   - latitude of current point (degrees)                        *
+*       dlon   - longitude of current point (degrees)                       *
+*       cont   - segment continuation flag.                                 *
 *       nsegs  - number of segments in this cell                            *
 *       npts   - number of points in this segment                           *
 *       total  - total points in this cell                                  *
@@ -383,8 +394,8 @@ static int celchk (int rindex, int logrec, int offset, FILE *fp, long *pcaddr)
 *                                                                           *
 ****************************************************************************/
 
-static void build_seg (float dlat, float dlon, int *cont, int *nsegs, 
-                       int *npts, int *total, float **latray, float **lonray, 
+static void build_seg (float dlat, float dlon, int *cont, int *nsegs,
+                       int *npts, int *total, float **latray, float **lonray,
                        int **segray, int lnbias)
 {
     /*  If this is beginning of a new segment, close the last segment.  */
@@ -395,7 +406,7 @@ static void build_seg (float dlat, float dlon, int *cont, int *nsegs,
 
         if (*npts > 0)
         {
-            if ((*segray = (int *) realloc (*segray, (*nsegs + 1) * 
+            if ((*segray = (int *) realloc (*segray, (*nsegs + 1) *
                 sizeof (int))) == NULL)
             {
                 perror (__FILE__);
@@ -403,13 +414,13 @@ static void build_seg (float dlat, float dlon, int *cont, int *nsegs,
             }
 
             (*segray)[*nsegs] = *npts + 1;
-            (*nsegs)++;
+            ++(*nsegs);
         }
         else
         {
             /*  Back up a spot if we got a single point segment.  */
 
-            if (*total >= 0) (*total)--;
+            if (*total >= 0) --(*total);
         }
 
         *npts = -1;
@@ -418,11 +429,11 @@ static void build_seg (float dlat, float dlon, int *cont, int *nsegs,
 
     /*  Reallocate memory and store point.  */
 
-    (*npts)++;
-    (*total)++;
+    ++(*npts);
+    ++(*total);
 
-    if ((*latray = (float *) realloc (*latray, ((*total) + 1) * 
-        sizeof (float))) == NULL || (*lonray = (float *) realloc (*lonray, 
+    if ((*latray = (float *) realloc (*latray, ((*total) + 1) *
+        sizeof (float))) == NULL || (*lonray = (float *) realloc (*lonray,
         ((*total) + 1) * sizeof (float))) == NULL)
     {
         perror (__FILE__);
@@ -512,6 +523,7 @@ static void build_seg (float dlat, float dlon, int *cont, int *nsegs,
 *                                                                           *
 *       file   - NGDC Global Relief Data file name (wvsfull.dat, etc) or    *
 *                "clean" to clear up memory, close files, etc.              *
+*       dir    - directory containing WVS files (WVS_DIR)                   *
 *       latd   - integer latitude degrees of one-degree cell (SW corner).   *
 *       lond   - integer longitude degrees of one-degree cell (SW corner).  *
 *       latray - array containing latitude points (returned)                *
@@ -522,35 +534,37 @@ static void build_seg (float dlat, float dlon, int *cont, int *nsegs,
 *                                                                           *
 \***************************************************************************/
 
-int wvsrtv (char *file, int latd, int lond, float **latray, float **lonray, 
-int **segray)
-{
+namespace Global {
+int wvsrtv (char const * const file,
+            char const * const dir,
+            int latd,
+            int lond,
+            float **latray,
+            float **lonray,
+            int **segray) {
     static FILE             *fp = NULL;
-    static char             prev_file[60], files[6][12] = 
-                            {"wvsfull.dat", "wvs250k.dat", "wvs1.dat", 
+    static char             prev_file[60], files[6][12] =
+                            {"wvsfull.dat", "wvs250k.dat", "wvs1.dat",
                             "wvs3.dat", "wvs12.dat", "wvs43.dat"};
-    static int              logrec, lperp, offset, version, slatf, nlatf, 
-                            wlonf, elonf, widef, ioff, first = 1, npts;
+    static int              logrec, lperp, offset, version, slatf, nlatf,
+                            wlonf, elonf, widef, ioff, npts;
+    static bool             first = true;
     static long             rindex, addr, paddr, curpos, fulrec, size, pcaddr;
     static float            todeg;
 
     unsigned char           bytbuf[PHYSIZ];
-    int                     i, j, col, segcnt, stat, lat, lon, nsegs, total,
-                            cont, cnt, latsec, lonsec, eflag, lnbias;
+    int                     i, j, col, segcnt, lat, lon, nsegs, total,
+                            cont, cnt, latsec, lonsec, lnbias;
+    bool                    eflag;
     long                    latoff, lonoff, conbyt, lats, lons;
-    char                    dirfil[512], dir[512], tmpfil[512];
+    char                    dirfil[512], tmpfil[512];
     float                   dlat, dlon;
 
 
 
-#ifdef DEBUG
-    fprintf (stderr, "%s %d\n", __FILE__, __LINE__);
-#endif
-
-
     /*  On the first call, set the arrays that will be malloc'ed to NULL.
-        This is so that the user doesn't have to remember to do it (I 
-        always forget).  They will be freed and reset on subsequent 
+        This is so that the user doesn't have to remember to do it (I
+        always forget).  They will be freed and reset on subsequent
         "clean" calls.  */
 
     if (first)
@@ -559,7 +573,7 @@ int **segray)
         *lonray = (float *) NULL;
         *segray = (int *) NULL;
 
-        first = 0;
+        first = false;
     }
 
 
@@ -586,7 +600,7 @@ int **segray)
 
 
     /*  Initialize variables, open file and read first record.  */
- 
+
     nsegs = 0;
     npts = -1;
     total = -1;
@@ -596,6 +610,10 @@ int **segray)
     lons = 0;
     lnbias = 0;
 
+    // DWF added error checking--protect 512-char buffer.
+    assert (dir);
+    assert (strlen(dir) + strlen(DIR_PATH_CHAR) + 11 < 512);
+
 
     /*  Have we changed files?  */
 
@@ -625,44 +643,15 @@ int **segray)
 
         /*  Don't handle the CIA WDB II files (they suck anyway).  */
 
-        if (!strcmp (file, "coasts.dat") || !strcmp (file, "rivers.dat") ||
+        if (!strcmp (file, "coasts.dat") ||
+            !strcmp (file, "rivers.dat") ||
             !strcmp (file, "bounds.dat")) return (0);
 
-        // DWF: revised to enable /etc/xtide.conf 2002-03-05
-        // (This code will break if the paths get too long)
-        {
-          dir[0] = '\0';
-          char *e = getenv ("WVS_DIR");
-          if (e != NULL) {
-            // DWF: dir has length 512, but so does dirfil, so leave room.
-            assert (strlen (e) <= 499);
-            strcpy (dir, e);
-          }
-#ifdef SUPER_ULTRA_VERBOSE_DEBUGGING
-          else
-            fprintf (stderr,
-                "\n\nEnvironment variable WVS_DIR is not set\n\n");
-#endif
-          if (dir[0] == '\0') {
-            FILE *configfile;
-            Dstr buf;
-            if ((configfile = fopen ("/etc/xtide.conf", "r"))) {
-              buf.getline (configfile);
-              buf.getline (configfile);
-              fclose (configfile);
-              if (buf.isNull())
-                return 0;
-              assert (buf.length() <= 499);
-              strcpy (dir, buf.aschar());
-            }
-          }
-        }
-
-        /*  Determine the resolution of the file so that we can go to lower 
+        /*  Determine the resolution of the file so that we can go to lower
             resolution if it is not available.  */
 
         strcpy (tmpfil, file);
-        for (i = 0 ; i < 6 ; i++)
+        for (i = 0 ; i < 6 ; ++i)
         {
             if (!strcmp (files[i], tmpfil))
             {
@@ -672,20 +661,20 @@ int **segray)
                 fp = fopen (dirfil, "rb");
 
 
-                /*  No lower resolution files were available, look for 
+                /*  No lower resolution files were available, look for
                     higher.  */
 
-                if (fp == NULL && i == 5) 
+                if (fp == NULL && i == 5)
                 {
                     strcpy (tmpfil, file);
-                    for (j = 5 ; j >= 0 ; j--)
+                    for (j = 5 ; j >= 0 ; --j)
                     {
                         if (!strcmp (files[j], tmpfil))
                         {
                             // RWL Put in for Windoze
 
-                            sprintf (dirfil, "%s%s%s", dir, DIR_PATH_CHAR, 
-                                tmpfil);
+                            sprintf (dirfil, "%s%s%s", dir, DIR_PATH_CHAR,
+                                     tmpfil);
                             fp = fopen (dirfil, "rb");
                             if (fp != NULL) break;
 
@@ -698,7 +687,7 @@ int **segray)
                         }
                     }
                 }
-                    
+
                 if (fp != NULL) break;
 
                 strcpy (tmpfil, files[i + 1]);
@@ -708,8 +697,16 @@ int **segray)
 
         /*  Get the file info (we actually looked at sub-setting these).  */
 
-        stat = fseek (fp, 0, 0);
-        stat = fread (bytbuf, 3072, 1, fp);
+        // DWF added error checking
+        if (fseek (fp, 0, 0)) {
+          fprintf (stderr, "wvsrtv:  error on first fseek\n");
+          perror (prev_file);
+          exit (-1);
+        }
+        if (fread (bytbuf, PHYSIZ, 1, fp) < 1) {
+          fprintf (stderr, "wvsrtv:  error on first fread\n");
+          exit (-1);
+        }
         logrec = bytbuf[3];
         fulrec = logrec - 4;
         version = bytbuf[4];
@@ -738,11 +735,11 @@ int **segray)
 
 
     /*  Compute integer values for retrieval and adjust if necessary. */
-    
+
     lat = latd + 90;
     lon = lond;
 
- 
+
     col = lon % 360;
     if (col < -180) col = col + 360;
     if (col >= 180) col = col - 360;
@@ -757,38 +754,44 @@ int **segray)
         !(celchk (rindex, logrec, offset, fp, &pcaddr))) return (0);
 
 
-    /*  Compute physical record address, read record and save as previous 
+    /*  Compute physical record address, read record and save as previous
         address.  */
 
-    eflag = 0;
+    eflag = false;
     addr = ((rindex - 1) / lperp) * PHYSIZ;
     if (addr != paddr)
     {
-        stat = fseek (fp, addr, 0);
-        stat = fread (bytbuf, PHYSIZ, 1, fp);
+      // DWF added error checking
+      if (fseek (fp, addr, 0)) {
+        fprintf (stderr, "wvsrtv:  error on second fseek\n");
+        perror (prev_file);
+        exit (-1);
+      }
+      if (fread (bytbuf, PHYSIZ, 1, fp) < 1) {
+        fprintf (stderr, "wvsrtv:  error on second fread\n");
+        exit (-1);
+      }
     }
     paddr = addr;
 
 
     /*  Compute byte position within physical record.  */
-                
+
     curpos = ((rindex - 1) % lperp) * logrec;
 
-
     /*  If not at end of segment, process the record.  */
-                
+
     while (!eflag)
     {
-        /*  Get first two bytes of header and break out count and 
+        /*  Get first two bytes of header and break out count and
             continuation bit.  */
-                    
+
         segcnt = (bytbuf[curpos] % 128) * 4 + bytbuf[curpos + 1] / 64 + 1;
         cont = bytbuf[curpos] / 128;
 
-
-        /*  If this is a continuation record get offsets from the second 
+        /*  If this is a continuation record get offsets from the second
             byte.  */
-                    
+
         if (cont)
         {
             latoff = ((bytbuf[curpos + 1] % 64) / 8) * (long) 65536;
@@ -797,37 +800,40 @@ int **segray)
 
 
         /*  If this is an initial record set the offsets to zero.  */
-                    
+
         else
         {
             latoff = 0;
             lonoff = 0;
+            // Additional in WVS1993 decoder
+            // short rank = bytbuf[curpos+1]%64;
+            // fprintf (stderr, "rank = %d\n", rank);
         }
 
 
-        /*  Update the current byte position and get a new record if 
+        /*  Update the current byte position and get a new record if
             necessary.  */
-                    
-        movpos (&rindex, bytbuf, &curpos, &addr, lperp, &paddr, fp, logrec, 
+
+        movpos (&rindex, bytbuf, &curpos, &addr, lperp, &paddr, fp, logrec,
             fulrec);
 
 
         /*  Compute the rest of the latitude offset.  */
-                    
+
         latoff += bytbuf[curpos] * (long) 256 + bytbuf[curpos + 1];
- 
-        movpos (&rindex, bytbuf, &curpos, &addr, lperp, &paddr, fp, logrec, 
+
+        movpos (&rindex, bytbuf, &curpos, &addr, lperp, &paddr, fp, logrec,
             fulrec);
 
 
         /*  Compute the rest of the longitude offset.  */
-                    
+
         lonoff += bytbuf[curpos] * (long) 256 + bytbuf[curpos + 1];
 
 
         /*  If this is a continuation record, bias the lat and lon offsets
             and compute the position.  */
-                    
+
         if (cont)
         {
             latoff -= 262144;
@@ -838,7 +844,7 @@ int **segray)
 
 
         /*  Else, compute the position.             */
-                    
+
         else
         {
             lats = (int) (lat * todeg) + latoff;
@@ -853,46 +859,46 @@ int **segray)
 
 
         /*  Update the current byte position.       */
-                    
+
         curpos += 2;
 
 
         /*  Get the continuation pointer.           */
-                    
+
         conbyt = ((rindex-1) % lperp) * logrec + fulrec;
 
 
-        /*  If there is no continuation pointer or the byte position is 
-            not at the position pointed to by the continuation pointer, 
+        /*  If there is no continuation pointer or the byte position is
+            not at the position pointed to by the continuation pointer,
             process the segment data.  */
-                    
-        if (bytbuf[conbyt] == 0 || (curpos + 1) % logrec <= 
+
+        if (bytbuf[conbyt] == 0 || (curpos + 1) % logrec <=
             bytbuf[conbyt])
         {
-            /*  If at the end of the logical record, get the next record 
+            /*  If at the end of the logical record, get the next record
                 in the chain.  */
-                        
-            if (curpos % logrec == fulrec && bytbuf[conbyt] == 0) 
-                nxtrec (&rindex, bytbuf, &curpos, &addr, lperp, &paddr, 
+
+            if (curpos % logrec == fulrec && bytbuf[conbyt] == 0)
+                nxtrec (&rindex, bytbuf, &curpos, &addr, lperp, &paddr,
                 fp, logrec);
 
-            build_seg (dlat, dlon, &cont, &nsegs, &npts, &total, latray, 
-                lonray, segray, lnbias); 
+            build_seg (dlat, dlon, &cont, &nsegs, &npts, &total, latray,
+                lonray, segray, lnbias);
 
 
-            /*  If the end of the segment has been reached, set the end 
+            /*  If the end of the segment has been reached, set the end
                 flag.  */
-                        
-            if ((curpos + 1) % logrec == bytbuf[conbyt]) eflag = 1;
+
+            if ((curpos + 1) % logrec == bytbuf[conbyt]) eflag = true;
 
 
             /*  Process the segment.                */
 
-            for (cnt = 2 ; cnt <= segcnt ; cnt++)
+            for (cnt = 2 ; cnt <= segcnt ; ++cnt)
             {
 
                 /*  Compute the position from the delta record.  */
-                            
+
                 latsec = bytbuf[curpos] - 128;
                 lats += latsec;
                 dlat = (float) lats / todeg;
@@ -901,8 +907,8 @@ int **segray)
                 dlon = (float) lons / todeg;
 
 
-                build_seg (dlat, dlon, &cont, &nsegs, &npts, &total, latray, 
-                    lonray, segray, lnbias); 
+                build_seg (dlat, dlon, &cont, &nsegs, &npts, &total, latray,
+                    lonray, segray, lnbias);
 
 
                 curpos += 2;
@@ -910,24 +916,24 @@ int **segray)
                 conbyt = ((rindex - 1) % lperp) * logrec + fulrec;
 
 
-                /*  If the end of the segment has been reached, set the 
+                /*  If the end of the segment has been reached, set the
                     end flag and break out of for loop.  */
-                            
+
                 if ((curpos + 1) % logrec == bytbuf[conbyt])
                 {
-                    eflag = 1;
+                    eflag = true;
                     break;
                 }
                 else
                 {
-                    if (curpos % logrec == fulrec) nxtrec (&rindex, 
+                    if (curpos % logrec == fulrec) nxtrec (&rindex,
                         bytbuf, &curpos, &addr, lperp, &paddr, fp, logrec);
                 }
             }
         }
 
         /*  Break out of while loop if at the end of the segment.  */
-                    
+
         else
         {
             break;
@@ -935,17 +941,15 @@ int **segray)
     }                               /*  end while   */
 
 
-    /*	Call the build_seg routine to flush the buffers.  */
+    /*  Call the build_seg routine to flush the buffers.  */
 
     cont = 0;
-    build_seg (999.0, 999.0, &cont, &nsegs, &npts, &total, latray, lonray, 
-        segray, lnbias); 
-
-
-#ifdef DEBUG
-    fprintf (stderr, "%s %d\n", __FILE__, __LINE__);
-#endif    
+    build_seg (999.0, 999.0, &cont, &nsegs, &npts, &total, latray, lonray,
+        segray, lnbias);
 
 
     return (nsegs);
 }
+}
+
+// Cleanup2006 Cruft ThirdPartyCode WontFix
